<?php
header("Content-Type: text/html; charset=utf-8");
session_start();
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('memory_limit', '1024M');

if (version_compare(phpversion(), '5.7', '<')) {
	$path = dirname(__DIR__) . '/includes';
} else {
	$path = dirname(__FILE__);
}

require_once($path . "/config.php");
require_once($path . "/data.php");
require_once($path . "/tpl.php");
require_once($path . "/main.php");

$tpl = new Template();
$qa = new QA_CLASS();
$qa->set_timezone(QA_TIMEZONE);

$language = $qa->_lang;

if (empty($language)) {
	$language = LANGUAGE;
}

if (file_exists($path . '/languages/' . $language . '.php')) {
	if ($language != 'ar') {
		require_once($path . '/languages/en.php');
	}
	require_once($path . '/languages/' . $language . '.php');
} else {
	require_once($path . '/languages/ar.php');
}

$langsList = [];
foreach ($qa->languages() as $k => $v) {
	$l = $qa->baseurl(get_url(['l' => $k], QA_REWRITERULE));
	if ($k == LANGUAGE) {
		$l = $qa->url();
	}

	$langsList[] = [
		'id' => $k,
		'title' => $v['name'],
		'url' => $l,
		'ar' => $v['ar'],
		'image' => $v['image']
	];
}

$main_menu = [
	[
		'title' => '<i class="fa-solid fa-house-chimney"></i> ' . $w['home'],
		'url' => $qa->url()
	],
	[
		'title' => '<i class="fa-solid fa-user-pen"></i> ' . $w['about_author'],
		'url' => $qa->baseurl(get_url(['l' => $language, 'action' => 'about'], QA_REWRITERULE))
	],
	[
		'title' => '<i class="fa-solid fa-earth-americas"></i> ' . $w['languages'],
		'url' => '#',
		'attr' => 'data-bs-toggle="modal" data-bs-target="#languahesModal"',
		'child' => $langsList
	],
];

$lang_html = '<div class="qa-modal-languages">';
$lang_html .= '<div class="row g-3">';
foreach ($langsList as $kl => $vl) {
	$countryName = $vl['title'];

	$img = '<img src="' . $qa->baseurl('images/flags/' . $vl['id'] . '.png') . '" alt="' . $countryName . '" class="mw-100">';

	$langLink = $vl['url'];

	$className = 'border rounded text-center p-3';
	$classNameCol = 'col-6 col-sm-4 col-md-3';

	if (empty($language) && $kl == LANGUAGE) {
		$getLink = $img . '<br />' . $countryName;
	} else {
		if ($vl['id'] == LANGUAGE) {
			$langLink = $qa->url();
		}

		if ($language == $vl['id']) {
			$className .= ' text-bg-secondary';
			$getLink = $img . '<br />' . $countryName;
		} else {
			$getLink = '<a class="d-block" href="' . $langLink . '">';
			$getLink .= $img . '<br />' . $countryName;
			$getLink .= '</a>';
		}
	}
	$lang_html .= '<div class="' . $classNameCol . '">';
	$lang_html .= '<div class="' . $className . '">';

	$lang_html .= $getLink;

	$lang_html .= '</div>';
	$lang_html .= '</div>';
}
$lang_html .= '</div>';
$lang_html .= '</div>';

$modal = '<div class="modal fade" id="languahesModal" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1" aria-labelledby="languahesModalLabel" aria-hidden="true">
  <div class="modal-dialog modal-xl">
    <div class="modal-content">
      <div class="modal-header">
        <h1 class="modal-title fs-5" id="languahesModalLabel">' . $w['languages'] . '</h1>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
      </div>
      <div class="modal-body">
		' . $lang_html . '
      </div>
    </div>
  </div>
</div>';

$qa->rewriterule = QA_REWRITERULE;
$qa->inc_path = $path;
$qa->data =  $data;

$tpl->body_class = QA_THEME_COLOR;
$tpl->languages = $qa->languages();
$tpl->theme_url = QA_THEME;
$tpl->site_name = $w['site_name'];
$tpl->site_url = $qa->url();
$tpl->site_description = QA_SITE_DESC;
$tpl->site_logo = QA_SITE_LOGO;
$tpl->site_language = $language;
$tpl->site_tagline = QA_SITE_TAGLINE;
$tpl->close_site_allow = QA_SITE_CLOSE;
$tpl->close_site = QA_SITE_CLOSE_CAUSE;
$tpl->header_code = QA_HEADER_CODE;
$tpl->footer_code = QA_FOOTER_CODE . $modal;
$tpl->body_top_code = QA_TOP_BODY_CODE;
$tpl->body_bottom_code = QA_BELOW_BODY_CODE;
$tpl->social_media = QA_SOCIAL_MEDIA;
$tpl->top_menu = QA_TOP_MENU;
$tpl->main_menu = $main_menu; //QA_MAIN_MENU;

$footer_wrapper = [];
/*
$footer_wrapper[] = [
	'title' => 'Title 1',
	'text' => 'Text 1',
];
$footer_wrapper[] = [
	'title' => 'Title 2',
	'text' => 'Text 2',
];
$footer_wrapper[] = [
	'title' => 'Title 3',
	'text' => 'Text 3',
];
$footer_wrapper[] = [
	'title' => 'Title 4',
	'text' => 'Text 4',
];
$footer_wrapper[] = [
	'title' => 'Title 5',
	'text' => 'Text 5',
];
$footer_wrapper[] = [
	'title' => 'Title 6',
	'text' => 'Text 6',
];
*/
$tpl->footer_wrapper = $footer_wrapper;
$tpl->hide_top_menu = true;
$tpl->main_menu_line = false;
$tpl->lazy_loading = true;
$tpl->navbar_sticky = false;
$tpl->overlay = true;
$tpl->overlay_navigation = true;

$tpl->home_header_code = '';
$tpl->home_body_code = '';
$tpl->home_footer_code = '';
$tpl->full_screen = true;
$tpl->breadcrumb_hide = false;

function get_url($info = [], $rewriterule = false)
{
	$url = '';

	$i = 0;
	foreach ($info as $k => $v) {
		$i++;
		if ($rewriterule) {
			$url .= $v . '/';
			if ($i > 1) {
				//$url .= '/';
			}
		} else {
			if ($i == 1) {
				$url .= 'index.php?';
				$url .= $k . '=' . $v;
			} else {
				$url .= '&' . $k . '=' . $v;
			}
		}
	}
	return $url;
}

function cuttext($limit = 200, $text = "", $end_text = '...')
{
	if (strlen($text) < $limit) {
		return $text;
	}
	$split_words = explode(' ', $text);
	$out = '';
	foreach ($split_words as $w) {
		if ((strlen($w) > $limit) && $out == null) {
			return substr($w, 0, $limit) . $end_text;
		}

		if ((strlen($out) + strlen($w)) > $limit) {
			return $out . $end_text;
		}
		$out .= " " . $w;
	}
	return $out;
}

function get_words($key, $lang = 'ar', $arr = false)
{
	global $w;
	if ($arr) {
		return $w;
	} else {
		return (is_array($w) && array_key_exists($key, $w) ? $w[$key] : 'Key ' . $key . ' not found');
	}
}

function word_id($matches = [])
{
	return get_words($matches[1]);
}

function url_id($matches = [])
{
	return get_url($matches[1]);
}
