<?php
class QA_CLASS
{
	public $sitename;
	public $tpl;
	public $data;
	public $current_page_protocol;
	public $current_page_site;
	public $current_page_thisfile;
	public $current_page_real_directories;
	public $current_page_num_of_real_directories;
	public $current_page_virtual_directories = [];
	public $current_page_num_of_virtual_directories = [];
	public $current_page_baseurl;
	public $current_page_thisurl;
	public $version;
	public $script_name = 'What Muslim Children Must Know';
	public $cache_folder;
	public $inc_path;

	public $current_url;
	public $_url;
	public $_lang;
	public $_action;
	public $_id;
	public $_id2;
	public $_pager = 1;
	public $_params;
	public $rewriterule = false;

	public function __construct()
	{
		global $tpl;
		$this->tpl = $tpl;
		$this->current_page_protocol = (isset($_SERVER['HTTPS']) ? 'https' : 'http');
		$this->current_page_site = $this->current_page_protocol . '://' . $_SERVER['HTTP_HOST'];
		$this->current_page_thisfile = basename($_SERVER['SCRIPT_FILENAME']);
		$this->current_page_real_directories = $this->cleanUp(explode("/", str_replace($this->current_page_thisfile, "", $_SERVER['PHP_SELF'])));
		$this->current_page_num_of_real_directories = count($this->current_page_real_directories);
		$this->current_page_virtual_directories = array_diff($this->cleanUp(explode("/", str_replace($this->current_page_thisfile, "", $_SERVER['REQUEST_URI']))), $this->current_page_real_directories);
		$this->current_page_num_of_virtual_directories = count($this->current_page_virtual_directories);
		$this->current_page_baseurl = $this->current_page_site . "/" . implode("/", $this->current_page_real_directories) . "/";
		$this->current_page_thisurl = $this->current_page_baseurl . implode("/", $this->current_page_virtual_directories) . "";

		$current_url = str_replace($this->current_page_baseurl, '', $this->current_page_thisurl);
		$url = trim($current_url, '/');

		$this->current_url = $url;
		$url_explode = explode('/', $url, 4);

		$url_array = [];
		if (isset($url_explode[0]) && !empty($url_explode[0])) {
			$this->_lang = $url_explode[0];
			$url_array[0] = $this->_lang;
		}
		if (isset($url_explode[1]) && !empty($url_explode[1])) {
			$this->_action = $url_explode[1];
			$url_array[1] = $this->_action;
		}
		if (isset($url_explode[2]) && !empty($url_explode[2])) {
			$this->_id = $this->slug_decoding($url_explode[2]);
			$url_array[2] = $this->_id;
		}
		if (isset($url_explode[3]) && !empty($url_explode[3])) {
			$this->_id2 = $this->slug_decoding($url_explode[3]);
			$url_array[3] = $this->_id2;
		}
		if (isset($url_explode[4]) && !empty($url_explode[4])) {
			$this->_pager = intval($url_explode[4]);
			$url_array[4] = $this->_pager;
		}
		if (isset($url_explode[5]) && !empty($url_explode[5])) {
			$params = explode('/', trim($url_explode[5]));
			$this->_params = $params;
			$url_array[5] = $params;
		}

		$this->_url = $url_array;

		$this->cache_folder = (empty($this->cache_folder) ? $this->inc_path . '/cache/' : trim($this->cache_folder, '/') . '/');
	}

	public function cleanUp($array)
	{
		$cleaned_array = array();
		foreach ($array as $key => $value) {
			$qpos = strpos($value, "?");
			if ($qpos !== false) {
				break;
			}
			if ($key != "" && $value != "") {
				$cleaned_array[] = $value;
			}
		}
		return $cleaned_array;
	}

	public function filter_text($text, $allow_html = false, $int = false)
	{
		if ($int) {
			return intval($text);
		}
		$text = trim($text);
		$text = stripslashes($text);
		if (!$allow_html) {
			$text = htmlspecialchars($text);
		}
		return $text;
	}

	public function slug_decoding($text)
	{
		return urldecode($text);
	}

	public function set_timezone($imezone = '')
	{
		$get_imezone = 'Asia/Kuwait';
		if (!empty($imezone)) {
			$get_imezone = $imezone;
		}

		if (!empty($get_imezone)) {
			date_default_timezone_set($get_imezone);
		}
	}

	public function baseurl($url = '')
	{
		$get_url_site = rtrim($this->current_page_baseurl, '/');
		return $get_url_site . '/' . $url;
	}

	public function lang($w)
	{
		$lang = (isset($_GET['lang']) ? strip_tags($_GET['lang']) : 'ar');
		$get_words = get_words($w, $lang);
		return $get_words;
	}

	public function url($info = [])
	{
		$url = get_url($info, $this->rewriterule);
		return $this->baseurl($url);
	}

	public function slug($str, $limit = null)
	{
		if ($limit) {
			$str = mb_substr($str, 0, $limit, "utf-8");
		}
		$text = html_entity_decode($str, ENT_QUOTES, 'UTF-8');
		$text = preg_replace('~[^\\pL\d]+~u', '-', $text);
		$text = trim($text, '-');
		return $text;
	}

	public static function sort(array &$rows, array $sorts)
	{
		$args = [];

		foreach ($sorts as $field => $direction) {
			$col = array_column($rows, $field);
			$args[] = $col;

			if ('asc' === $direction) {
				$args[] = SORT_ASC;
			} else {
				$args[] = SORT_DESC;
			}
		}
		$args[] = &$rows;
		call_user_func_array("array_multisort", $args);
	}

	public function action()
	{
		$action = (isset($_GET['action']) ? strip_tags($_GET['action']) : 'home');
		return $action;
	}

	public function languages()
	{

		$lang = [];
		$lang['ar'] = [
			'name' => 'العربية',
			'ar' => 'العربية',
			'image' => $this->baseurl('images/og/ar.jpg')
		];

		$lang['en'] = [
			'name' => 'English',
			'ar' => 'إنجليزي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['fr'] = [
			'name' => 'Français',
			'ar' => 'فرنسي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['es'] = [
			'name' => 'Español',
			'ar' => 'إسباني',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['pt'] = [
			'name' => 'português',
			'ar' => 'برتغالي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['sq'] = [
			'name' => 'Shqip',
			'ar' => 'ألباني',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['bs'] = [
			'name' => 'bosanski',
			'ar' => 'بوسني',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['az'] = [
			'name' => 'azərbaycanca',
			'ar' => 'أذري',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['ru'] = [
			'name' => 'Русский',
			'ar' => 'روسي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['ro'] = [
			'name' => 'română',
			'ar' => 'روماني',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['ha'] = [
			'name' => 'Hausa',
			'ar' => 'هوسا',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['sw'] = [
			'name' => 'Kiswahili',
			'ar' => 'سواحيلي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['am'] = [
			'name' => 'አማርኛ',
			'ar' => 'أمهري',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['ur'] = [
			'name' => 'اردو',
			'ar' => 'اردو',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['ps'] = [
			'name' => 'پښتو',
			'ar' => 'بشتو',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['hi'] = [
			'name' => 'हिन्दी',
			'ar' => 'هندي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['uz'] = [
			'name' => 'Ўзбек',
			'ar' => 'أوزبكي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['bn'] = [
			'name' => 'বাংলা',
			'ar' => 'بنغالي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['ml'] = [
			'name' => 'മലയാളം',
			'ar' => 'مليالم',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['yo'] = [
			'name' => 'Èdè Yorùbá',
			'ar' => 'يوربا',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['vi'] = [
			'name' => 'Tiếng Việt',
			'ar' => 'فيتنامي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['prs'] = [
			'name' => 'دری',
			'ar' => 'دری',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['as'] = [
			'name' => 'অসমীয়া',
			'ar' => 'آسامي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['mg'] = [
			'name' => 'Malagasy',
			'ar' => 'مالاغاشي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['km'] = [
			'name' => 'ភាសាខ្មែរ',
			'ar' => 'خميري',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['tl'] = [
			'name' => 'Wikang Tagalog',
			'ar' => 'تجالوج',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['si'] = [
			'name' => 'සිංහල',
			'ar' => 'سنهالي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['gu'] = [
			'name' => 'ગુજરાતી',
			'ar' => 'غوجراتي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['el'] = [
			'name' => 'ελληνικά',
			'ar' => 'يوناني',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['ff'] = [
			'name' => 'Pulaar',
			'ar' => 'فولاني',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['mos'] = [
			'name' => 'Mõõré',
			'ar' => 'موري',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['wo'] = [
			'name' => 'Wollof',
			'ar' => 'ولوف',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['ak'] = [
			'name' => 'Akan',
			'ar' => 'آكاني',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['rw'] = [
			'name' => 'Kinyarwanda',
			'ar' => 'كينيارواندي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['te'] = [
			'name' => 'తెలుగు',
			'ar' => 'تلغو',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['sv'] = [
			'name' => 'svenska',
			'ar' => 'سويدي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['ta'] = [
			'name' => 'தமிழ்',
			'ar' => 'تاميلي',
			'image' => $this->baseurl('images/og/ar.jpg')
		];
		$lang['lt'] = [
			'name' => 'lietuvių',
			'ar' => 'ليتواني',
			'image' => $this->baseurl('images/og/ar.jpg')
		];

		return $lang;
	}

	public function get_current_lang()
	{
		$lang = (isset($_GET['l']) ? strip_tags($_GET['l']) : '');
		if ($this->rewriterule) {
			$lang = $this->_lang;
		}

		$languages = $this->languages();
		if (!empty($lang)) {
			if (array_key_exists($lang, $languages)) {
				$lang = $lang;
			} else {
				$lang = LANGUAGE;
			}
		}

		return $lang;
	}


	public function replace_br($data)
	{
		$p1 = ['<p>', '</p>', 'c1', 'c2', 'c3', 'c4', 'c5', 'c6'];
		$p2 = ['', '', 'c_orange', 'c_green', 'c_red', 'c_yellow', 'c_gray', 'c_blue'];
		$data = str_replace($p1, $p2, $data);

		$data = explode('<br />', $data);
		if (is_array($data)) {
			$output = '';
			foreach ($data as $val) {
				$output .= '<p>';
				$output .= $val;
				$output .= '</p>';
			}
		} else {
			$output = $data;
		}

		return $output;
	}

	public function convert_digits($string)
	{
		$newNumbers = range(0, 9);
		// 1. Persian HTML decimal
		$persianDecimal = array('&#1776;', '&#1777;', '&#1778;', '&#1779;', '&#1780;', '&#1781;', '&#1782;', '&#1783;', '&#1784;', '&#1785;');
		// 2. Arabic HTML decimal
		$arabicDecimal = array('&#1632;', '&#1633;', '&#1634;', '&#1635;', '&#1636;', '&#1637;', '&#1638;', '&#1639;', '&#1640;', '&#1641;');
		// 3. Arabic Numeric
		$arabic = array('٠', '١', '٢', '٣', '٤', '٥', '٦', '٧', '٨', '٩');
		// 4. Persian Numeric
		$persian = array('۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹');

		$string =  str_replace($persianDecimal, $newNumbers, $string);
		$string =  str_replace($arabicDecimal, $newNumbers, $string);
		$string =  str_replace($newNumbers, $arabic, $string);
		return str_replace($newNumbers, $persian, $string);
	}

	public function categories($sections = [])
	{

		$aqeeda = (isset($sections[0]) && !empty($sections[0]) ? $sections[0] : $this->lang('aqeeda'));
		$fiqh = (isset($sections[1]) && !empty($sections[1]) ? $sections[1] : $this->lang('fiqh'));
		$seera = (isset($sections[2]) && !empty($sections[2]) ? $sections[2] : $this->lang('seera'));
		$tafseer = (isset($sections[3]) && !empty($sections[3]) ? $sections[3] : $this->lang('tafseer'));
		$hadeeth = (isset($sections[4]) && !empty($sections[4]) ? $sections[4] : $this->lang('hadeeth'));
		$adab = (isset($sections[5]) && !empty($sections[5]) ? $sections[5] : $this->lang('adab'));
		$akhlaq = (isset($sections[6]) && !empty($sections[6]) ? $sections[6] : $this->lang('akhlaq'));
		$adeiah = (isset($sections[7]) && !empty($sections[7]) ? $sections[7] : $this->lang('adeiah'));
		$misc = (isset($sections[8]) && !empty($sections[8]) ? $sections[8] : $this->lang('misc'));

		$arr = [];
		$arr[1] = [
			'name' => $aqeeda,
			'url' => 'https://kids.islamenc.com/ar/browse/category/10',
			'image' => 'images/icons/aqeeda.png',
			'icon' => 'images/icons/aqeeda-small.png'
		];

		$arr[2] = [
			'name' => $fiqh,
			'url' => 'https://kids.islamenc.com/ar/browse/category/20',
			'image' => 'images/icons/fiqh.png',
			'icon' => 'images/icons/fiqh-small.png'
		];

		$arr[3] = [
			'name' => $seera,
			'url' => 'https://kids.islamenc.com/ar/browse/category/30',
			'image' => 'images/icons/seera.png',
			'icon' => 'images/icons/seera-small.png'
		];

		$arr[4] = [
			'name' => $tafseer,
			'url' => 'https://kids.islamenc.com/ar/browse/category/40',
			'image' => 'images/icons/tafseer.png',
			'icon' => 'images/icons/tafseer-small.png'
		];

		$arr[5] = [
			'name' => $hadeeth,
			'url' => 'https://kids.islamenc.com/ar/browse/category/50',
			'image' => 'images/icons/hadeeth.png',
			'icon' => 'images/icons/hadeeth-small.png'
		];

		$arr[6] = [
			'name' => $adab,
			'url' => 'https://kids.islamenc.com/ar/browse/category/60',
			'image' => 'images/icons/adab.png',
			'icon' => 'images/icons/adab-small.png'
		];

		$arr[7] = [
			'name' => $akhlaq,
			'url' => 'https://kids.islamenc.com/ar/browse/category/70',
			'image' => 'images/icons/akhlaq.png',
			'icon' => 'images/icons/akhlaq-small.png'
		];

		$arr[8] = [
			'name' => $adeiah,
			'url' => 'https://kids.islamenc.com/ar/browse/category/80',
			'image' => 'images/icons/adeiah.png',
			'icon' => 'images/icons/adeiah-small.png'
		];

		$arr[9] = [
			'name' => $misc,
			'url' => 'https://kids.islamenc.com/ar/browse/category/90',
			'image' => 'images/icons/misc.png',
			'icon' => 'images/icons/misc-small.png'
		];

		return $arr;
	}

	public function output_home()
	{
		$qa = $this->data;
		$languages = $this->languages();
		$categories = $this->categories();
		$currentLang = $this->get_current_lang();

		$mainTitle = $qa['title'];
		$description = $qa['description'];

		if (empty($currentLang)) {
			$currentLang = LANGUAGE;
		}

		if (LANGUAGE != 'ar') {
			if (empty($currentLang)) {
				$currentLang = LANGUAGE;
			}
		}

		if (!empty($currentLang)) {
			if (file_exists($this->inc_path . '/data/' . $currentLang . '.php')) {
				require_once($this->inc_path . '/data/' . $currentLang . '.php');
				$d = $data;
				if (isset($d['title'])) {
					$mainTitle = $d['title'];
				}
				if (isset($d['description'])) {
					$description = $d['description'];
				}
				if (isset($d['sections'])) {
					$categories = $this->categories($d['sections']);
				}
			}
		}

		$this->tpl->title = $mainTitle;
		$this->tpl->description = $description;

		if (empty($currentLang) || $currentLang == LANGUAGE) {
			$this->tpl->url = $this->url();
			$this->tpl->image = (isset($languages[LANGUAGE]['image']) ? $languages[LANGUAGE]['image'] : '');
		} else {
			$this->tpl->url = $this->url(['l' => $currentLang]);
			$this->tpl->image = (isset($languages[$currentLang]['image']) ? $languages[$currentLang]['image'] : '');
		}

		$html = '<div class="container-home">';
		$html .= '<div class="container">';
		$html .= '<div class="container-body">';
		$html .= '<h1 class="title">' . $mainTitle . '</h1>';
		$html .= '<p class="subtitle">' . $description . '</p>';

		$html .= '<div class="row g-3">';
		foreach ($categories as $k => $v) {
			$url = $this->url(['l' => $currentLang, 'action' => 'section', 'id' => $k]);
			$html .= '<div class="col-12 col-sm-6 col-md-4">';
			$html .= '<div class="kids-card">';
			$html .= '<h3 class="kids-section-name">';
			$html .= '<a href="' . $url . '">';
			$html .= '<img class="kids-card-icon me-3" src="' . $this->baseurl($v['icon']) . '" alt="' . $v['name'] . '"> ';
			$html .= $v['name'];
			$html .= '</a>';
			$html .= '</h3>';
			$html .= '<img class="kids-card-img" src="' . $this->baseurl($v['image']) . '" alt="' . $v['name'] . '">';
			$html .= '</div>';
			$html .= '</div>';
		}
		$html .= '</div>';

		$html .= '</div>';
		$html .= '</div>';
		$html .= '</div>';

		return $this->tpl->view($html);
	}

	public function output_section()
	{
		$id = $this->tpl->_id;

		$qa = $this->data;
		$languages = $this->languages();
		$categories = $this->categories();
		$currentLang = $this->get_current_lang();

		$mainTitle = $qa['title'];
		$description = $qa['description'];
		$getData = $qa['data'];
		$mainIcon = '';
		$mainImage = '';

		$breadcrumb = [];

		foreach ($categories as $k_c => $v_c) {
			if ($k_c == $id) {
				$mainTitle = $v_c['name'];
				$mainIcon = $v_c['icon'];
				$mainImage = $v_c['image'];
			}
		}

		if (empty($currentLang)) {
			$currentLang = LANGUAGE;
		}

		if (LANGUAGE != 'ar') {
			if (empty($currentLang)) {
				$currentLang = LANGUAGE;
			}
		}

		if (!empty($currentLang)) {
			if (file_exists($this->inc_path . '/data/' . $currentLang . '.php')) {
				require_once($this->inc_path . '/data/' . $currentLang . '.php');
				$d = $data;
				if (isset($d['title'])) {
					$mainTitle = $d['title'];
				}
				if (isset($d['description'])) {
					$description = $d['description'];
				}
				if (isset($d['data'])) {
					$getData = $d['data'];
				}
				if (isset($d['sections'])) {
					$categories = $this->categories($d['sections']);
					foreach ($categories as $k_c2 => $v_c2) {
						if ($k_c2 == $id) {
							$mainTitle = $v_c2['name'];
						}
					}
				}
				$breadcrumb[] = [
					'title' => (isset($languages[$currentLang]['name']) ? $languages[$currentLang]['name'] : ''),
					'url' => $this->tpl->url = $this->url(['l' => $currentLang]),
				];
			}
		}

		$this->tpl->title = $mainTitle;
		$this->tpl->description = $mainTitle . ' - ' . $description;

		if (empty($currentLang)) {
			$this->tpl->url = $this->url();
			$this->tpl->image = (isset($languages[LANGUAGE]['image']) ? $languages[LANGUAGE]['image'] : '');
		} else {
			$this->tpl->url = $this->url(['l' => $currentLang, 'section' => $id]);
			$this->tpl->image = (isset($languages[$currentLang]['image']) ? $languages[$currentLang]['image'] : '');
		}

		$this->tpl->breadcrumb_list = $breadcrumb;

		$html = '<div class="container-home">';
		$html .= '<div class="container">';
		$html .= '<div class="container-body">';
		$html .= '<h1 class="title">' . $mainTitle . '</h1>';

		$html .= '<div class="question-list">';
		$html .= '<div class="accordion" id="accordionPanelsData">';
		$i = 0;
		foreach ($getData as $k => $v) {
			if ($id == $k) {
				if (is_array($v) && count($v)) {
					foreach ($v as $k2 => $v2) {
						$i++;
						$question = $v2['question'];
						$answer = $v2['answer'];
						$answer = $this->replace_br($answer);
						if( $currentLang == 'ar' ){
							$question = $this->convert_digits($question);
							$answer = $this->convert_digits($answer);
						}

						$audio = $v2['audio'];

						$url = $this->url(['l' => $currentLang, 'action' => 'show', 'id' => $k, 'post_id' => $i]);

						if ($i == 1) {
							$buttonClass = 'accordion-button';
							$aria_expanded = 'true';
							$collapseClass = 'accordion-collapse collapse show';
						} else {
							$buttonClass = 'accordion-button collapsed';
							$aria_expanded = 'false';
							$collapseClass = 'accordion-collapse collapse';
						}

						$html .= '<div class="accordion-item">';
						$html .= '<h2 class="accordion-header">';
						$html .= '<button class="' . $buttonClass . ' fw-bold" type="button" data-bs-toggle="collapse" data-bs-target="#data-' . $k2 . '" aria-expanded="' . $aria_expanded . '" aria-controls="data-' . $k2 . '">';
						//$html .= '<a href="' . $url . '">';
						$html .= $question;
						//$html .= '</a>';
						$html .= '</button>';
						$html .= '</h2>';
						$html .= '<div id="data-' . $k2 . '" class="' . $collapseClass . '">';
						$html .= '<div class="accordion-body">';
						$html .= $answer;
						$html .= '<p><a href="' . $url . '"><i class="fa-solid fa-arrow-up-right-from-square"></i></a></p>';
						$html .= '</div>';
						$html .= '</div>';
						$html .= '</div>';
					}
				}
			}
		}
		$html .= '</div>';
		$html .= '</div>';
		$html .= '</div>';

		$html .= '</div>';
		$html .= '</div>';

		return $this->tpl->view($html);
	}

	public function output_show()
	{
		$id = $this->tpl->_id;
		$post_id = $this->tpl->_id2;

		$post_id = intval($post_id);
		if ($post_id > 0) {
			$new_post_id = $post_id - 1;
		}

		$qa = $this->data;
		$languages = $this->languages();
		$categories = $this->categories();
		$currentLang = $this->get_current_lang();

		$mainTitle = $qa['title'];
		$description = $qa['description'];
		$getData = $qa['data'];

		$catTitle = '';
		$catLink = '';
		foreach ($categories as $k_c => $v_c) {
			if ($k_c == $id) {
				$catTitle = $v_c['name'];
				$catLink = $this->url(['l' => $currentLang, 'action' => 'section', 'id' => $id]);
			}
		}

		if (empty($currentLang)) {
			$currentLang = LANGUAGE;
		}

		if (LANGUAGE != 'ar') {
			if (empty($currentLang)) {
				$currentLang = LANGUAGE;
			}
		}

		$getLangName = ( isset($languages[$currentLang]['name']) ? $languages[$currentLang]['name'] : '' );
		$getLangLink = $this->url(['l' => $currentLang]);

		if (!empty($currentLang)) {
			if (file_exists($this->inc_path . '/data/' . $currentLang . '.php')) {
				require_once($this->inc_path . '/data/' . $currentLang . '.php');
				$d = $data;
				if (isset($d['title'])) {
					$mainTitle = $d['title'];
				}
				if (isset($d['description'])) {
					$description = $d['description'];
				}
				if (isset($d['data'])) {
					$getData = $d['data'];
				}
				$catTitle = '';
				if (isset($d['sections'])) {
					$categories = $this->categories($d['sections']);
					foreach ($categories as $k_c2 => $v_c2) {
						if ($k_c2 == $id) {
							$catTitle = $v_c2['name'];
						}
					}
				}
			}
		}

		$breadcrumb = [
			[
				'title' => $getLangName,
				'url' => $getLangLink,
			],
			[
				'title' => $catTitle,
				'url' => $catLink,
			]
		];

		$this->tpl->breadcrumb_list = $breadcrumb;

		$post_url = $this->url(['l' => $currentLang, 'action' => 'show', 'id' => $id, 'post_id' => $post_id]);

		if (isset($getData[$id][$new_post_id]) && is_array($getData[$id][$new_post_id])) {
			$v2 = $getData[$id][$new_post_id];
			$question = $v2['question'];
			$answer = $v2['answer'];
			$answer = $this->replace_br($answer);
			

			if( $currentLang == 'ar' ){
				$question = $this->convert_digits($question);
				$answer = $this->convert_digits($answer);
			}

			$mainTitle = $question;
			$description = $question;

			$audio = $v2['audio'];

			$html = '<div class="container-home">';
			$html .= '<div class="container">';
			$html .= '<div class="container-body">';
			$html .= '<h2 class="title">' . $question . '</h2>';

			$html .= '<div class="answer-body">';
			$html .= $answer;
			$html .= '</div>';
			$html .= '</div>';

			$html .= $this->tpl->share($mainTitle, $post_url);

			$html .= '</div>';
			$html .= '</div>';

			$this->tpl->url = $post_url;
		}else{
			$html = '<div class="qa-show-container">';
			$html .= '<div class="container">';
			$html .= '<div class="alert alert-danger">';
			$html .= '<P class="mb-0">' . $this->lang('not_found') . '</p>';
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';
		}

		$this->tpl->title = $mainTitle;
		$this->tpl->description = $description;
		
		return $this->tpl->view($html);
	}

	public function output_about()
	{
		$qa = $this->data;
		$languages = $this->languages();
		$categories = $this->categories();
		$currentLang = $this->get_current_lang();

		$mainTitle = $qa['title'];
		$description = $qa['description'];
		$author = (isset($qa['author']) ? $qa['author'] : '');
		$cover = (isset($qa['cover']) ? $qa['cover'] : '');
		$download = (isset($qa['download']) ? $qa['download'] : '');
		$source = (isset($qa['source']) ? $qa['source'] : '');

		if (empty($currentLang)) {
			$currentLang = LANGUAGE;
		}

		if (LANGUAGE != 'ar') {
			if (empty($currentLang)) {
				$currentLang = LANGUAGE;
			}
		}
		$cover_img = '';
		if (!empty($cover)) {
			$cover_img .= '<div class="text-center mb-4">';
			$cover_img .= '<img src="' . $this->baseurl($cover) . '" alt="' . $mainTitle . '" class="mw-100">';
			$cover_img .= '</div>';
			$cover_img .= '<hr />';
		}

		if (!empty($currentLang)) {
			if (file_exists($this->inc_path . '/data/' . $currentLang . '.php')) {
				require_once($this->inc_path . '/data/' . $currentLang . '.php');
				$d = $data;
				if (isset($d['title'])) {
					$mainTitle = $d['title'];
				}
				if (isset($d['description'])) {
					$description = $d['description'];
				}
				if (isset($d['author'])) {
					$author = $d['author'];
				}
				if (isset($d['sections'])) {
					$categories = $this->categories($d['sections']);
				}
			}
		}

		$this->tpl->title = $this->lang('about_author') . ' ' . $author;
		$this->tpl->description = $author . ' - ' . $description;

		if (empty($currentLang) || $currentLang == LANGUAGE) {
			$this->tpl->url = $this->url(['action' => 'about']);
			$this->tpl->image = (isset($languages[LANGUAGE]['image']) ? $languages[LANGUAGE]['image'] : '');
		} else {
			$this->tpl->url = $this->url(['l' => $currentLang, 'action' => 'about']);
			$this->tpl->image = (isset($languages[$currentLang]['image']) ? $languages[$currentLang]['image'] : '');
		}

		$lang_html = '<div class="qa-modal-languages">';
		$lang_html .= '<p class="text-center fw-bold">' . $this->lang('languages') . '</p>';
		$lang_html .= '<div class="row g-3">';
		foreach ($languages as $kl => $vl) {
			$countryName = (isset($vl['name']) ? $vl['name'] : $kl);
			$imageOG = (isset($vl['image']) ? $vl['image'] : '');

			$img = '<img src="' . $this->baseurl('images/flags/' . $kl . '.png') . '" alt="' . $countryName . '" class="mw-100">';

			$langLink = $this->url(['l' => $kl]);

			$className = 'border rounded text-center p-3';
			$classNameCol = 'col-4 col-md-3';

			if (empty($currentLang) && $kl == LANGUAGE) {
				$getLink .= $img . '<br />' . $countryName;
				$className .= ' text-bg-light';
			} else {
				if ($kl == LANGUAGE) {
					$langLink = $this->url();
				}
				if ($currentLang == $kl) {
					$className .= ' text-bg-secondary';
					$getLink = $img . '<br />' . $countryName;
				} else {
					$getLink = '<a class="d-block" href="' . $langLink . '">';
					$getLink .= $img . '<br />' . $countryName;
					$getLink .= '</a>';
					$className .= ' text-bg-light';
				}
			}

			$lang_html .= '<div class="' . $classNameCol . '">';
			$lang_html .= '<div class="' . $className . '">';

			$lang_html .= $getLink;

			$lang_html .= '</div>';
			$lang_html .= '</div>';
		}
		$lang_html .= '</div>';
		$lang_html .= '</div>';

		$html = '<div class="container-home">';
		$html .= '<div class="container">';
		$html .= '<div class="container-body">';
		$html .= '<h1 class="title">' . $author . '</h1>';
		$html .= '<h4 class="title">' . $mainTitle . '</h4>';
		$html .= '<p class="subtitle">' . $description . '</p>';

		$html .= '<div class="row g-3 text-center">';
		$html .= '<div class="col-6 col-md-6">';
		$html .= '<p><i class="fa-solid fa-file-pdf d-color"></i> <a href="' . $download . '" target="_blank">' . $this->lang('view_book') . '</a></p>';
		$html .= '</div>';
		$html .= '<div class="col-6 col-md-6">';
		$html .= '<p><i class="fa-solid fa-check-to-slot d-color"></i> <a href="' . $source . '" target="_blank">' . $this->lang('source') . '</a></p>';
		$html .= '</div>';
		$html .= '</div>';

		$html .= $cover_img;
		$html .= $lang_html;

		$html .= '</div>';
		$html .= '</div>';

		return $this->tpl->view($html);
	}

	public function output()
	{
		if( QA_SITE_CLOSE ){
			$html = '<div class="container-home">';
			$html .= '<div class="container">';
			$html .= '<div class="container-body">';
			$html .= QA_SITE_CLOSE_CAUSE;
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';
	
			return $this->tpl->view($html);
		}
		
		$action = $this->action();

		if ($this->rewriterule) {
			$action = $this->_action;
			$this->tpl->_lang = $this->_lang;
			$this->tpl->_action = $action;
			$this->tpl->_id = $this->_id;
			$this->tpl->_id2 = $this->_id2;
			$this->tpl->_pager = $this->_pager;
			$this->tpl->_params = $this->_params;
		} else {
			$this->tpl->_lang = (isset($_GET["l"]) ? strip_tags($_GET["l"]) : '');
			$this->tpl->_action = $action;
			$this->tpl->_id = (isset($_GET["id"]) ? intval($_GET["id"]) : 0);
			$this->tpl->_id2 = (isset($_GET["post_id"]) ? intval($_GET["post_id"]) : 0);
			$this->tpl->_pager = (isset($_GET["page"]) ? intval($_GET["page"]) : 1);
		}

		if (empty($action) && $this->tpl->_lang == 'about') {
			$action = $this->tpl->_lang;
		}

		if ($action == 'show') {
			$output = $this->output_show();
		} elseif ($action == 'section') {
			$output = $this->output_section();
		} elseif ($action == 'about') {
			$output = $this->output_about();
		} else {
			$output = $this->output_home();
		}

		return $output;
	}
}
